@@ -5,9 +5,6 @@
 #include <QMutex>
 #include <QByteArray>
 
-#define SAMPLE_RATE 44100
-#define CHANNELS    2
-
 PlaybackThread::PlaybackThread(QObject* parent)
     : QThread(parent)
 {
@@ -37,7 +34,7 @@ PlaybackThread::PlaybackThread(QObject* parent)
 
     m_pAudioStream = NULL;
 
-    buffer.maxlength = pa_usec_to_bytes(750000, &ss); //750ms
+    buffer.maxlength = pa_usec_to_bytes(1000000, &ss); //1000ms
     buffer.tlength = -1;
     buffer.prebuf = -1;
     buffer.minreq = -1;
