@@ -43,7 +43,7 @@ namespace Spotify
             }
 
             // Set tracks:
-            if( m_tracks.isEmpty() )
+           /* if( m_tracks.isEmpty() )
             {
                 int numTracks = sp_artistbrowse_num_tracks( m_artistbrowse );
                 for( int i = 0; i < numTracks; ++i )
@@ -58,6 +58,9 @@ namespace Spotify
                 }
             }
 
+            */
+
+
             if( m_similarArtists.isEmpty() )
             {
                 int numSimilarArtists = sp_artistbrowse_num_similar_artists( m_artistbrowse );
