@@ -1,6 +1,6 @@
 #ifndef SEARCH_H
 #define SEARCH_H
-#include <spotify/api.h>
+#include <libspotify/api.h>
 #include "trackcollection.h"
 #include "album.h"
 namespace Spotify
@@ -10,7 +10,7 @@ namespace Spotify
     {
 
         public:
-            Search( sp_search* search, QObject* parent = 0);
+            Search(sp_session* session, sp_search* search, QObject* parent = 0);
             ~Search();
 
             virtual bool load();
@@ -22,6 +22,7 @@ namespace Spotify
             QList< Spotify::Album* > getAlbums() const { return m_albums; }
 
         private:
+            sp_session* m_session;
             sp_search* m_search;
             QString m_searchQuery;
             QString m_sugguestions;
