@@ -82,10 +82,12 @@ QString Spotify::Session::getRememberedUser()
     {
         qint32 ret = sp_session_remembered_user(m_session,userID,sizeof(userID));
         if(ret!=-1)
-            return QString(userID);
+            return QString::fromUtf8(userID);
         else
             return QString();
     }
+    else
+        qDebug() << "No valid session!";
 
     return QString();
 }
@@ -1134,17 +1136,28 @@ void Spotify::Session::loggedInCallback( sp_session* session, sp_error error )
 void Spotify::Session::loggedInWrapper( Spotify::Error error )
 {
     // Let application know we're logged in (or not)
-   if(!m_playlistcontainer && !error.isError())
+    if(error.isError())
     {
-      if(!m_currentUser)
-          m_currentUser = new Spotify::User( sp_session_user( m_session ) );
-      qDebug() << "Registering container callbacks..";
-      m_playlistcontainer = sp_session_playlistcontainer(m_session); //get root playlist container
-      sp_playlistcontainer_add_callbacks(m_playlistcontainer,&pc_callbacks,NULL); //register callbacks
-      qDebug() << "Container callbacks registered..";
+        qDebug() << "Logged in with error: " << error.toString();
+    }
+    else
+        qDebug() << "Logged in OK..";
+
+    if(!m_currentUser)
+    {
+        m_currentUser = new Spotify::User( sp_session_user( m_session ) );
+        if(m_currentUser->isLoaded())
+            qDebug() << "User loaded OK..";
+    }
+    if(!m_playlistcontainer && !error.isError())
+    {
+        qDebug() << "Registering container callbacks..";
+        m_playlistcontainer = sp_session_playlistcontainer(m_session); //get root playlist container
+        sp_playlistcontainer_add_callbacks(m_playlistcontainer,&pc_callbacks,NULL); //register callbacks
+        qDebug() << "Container callbacks registered..";
     }
 
-   emit loggedIn( error );
+    emit loggedIn( error );
 }
 
 void Spotify::Session::loggedOutCallback( sp_session* session )
