@@ -67,7 +67,7 @@ bool Spotify::Track::load()
     {
        // qDebug()<<"Load track..";
         // Set availability:
-        m_available = sp_track_is_available(m_session, m_track );
+        m_available =  sp_track_get_availability(m_session, m_track );
 
 
         // Set artists:
@@ -126,6 +126,12 @@ bool Spotify::Track::load()
         // Set index:
         m_index = sp_track_index( m_track );
 
+        // Set track offline availability
+        if(sp_track_offline_get_status( m_track ) == SP_TRACK_OFFLINE_DONE)
+            m_isOffline = true;
+        else
+            m_isOffline = false;
+
         m_loaded = true;
         emit loaded();
     }
